@@ -65,24 +65,24 @@ HTTP::Proxy::HeaderFilter::simple - A class for creating simple filters
 
 =head1 DESCRIPTION
 
-HTTP::Proxy::HeaderFilter::simple can create BodyFilter without going
+L<HTTP::Proxy::HeaderFilter::simple> can create BodyFilter without going
 through the hassle of creating a full-fledged class. Simply pass
-a code reference to the filter() method of your filter to the constructor,
+a code reference to the C<filter()> method of your filter to the constructor,
 and you'll get the adequate filter.
 
 =head2 Constructor calling convention
 
 The constructor is called with a single code reference.
-The code reference must conform to the standard filter() signature
+The code reference must conform to the standard C<filter()> signature
 for header filters:
 
     sub filter { my ( $self, $headers, $message) = @_; ... }
 
-This code reference is used for the filter() method.
+This code reference is used for the C<filter()> method.
 
 =head1 METHODS
 
-This filter "factory" defines the standard HTTP::Proxy::HeaderFilter
+This filter "factory" defines the standard L<HTTP::Proxy::HeaderFilter>
 methods, but those are only, erm, "proxies" to the actual CODE references
 passed to the constructor. These "proxy" methods are:
 
@@ -96,7 +96,7 @@ passed to the constructor. These "proxy" methods are:
 
 =back
 
-Two other methods are actually HTTP::Proxy::HeaderFilter::simple methods,
+Two other methods are actually L<HTTP::Proxy::HeaderFilter::simple> methods,
 and are called automatically:
 
 =over 4
@@ -110,7 +110,7 @@ constructor.
 
 Return the actual code reference that will be run, and not the "proxy"
 methods. If called with any other name than C<begin> and C<filter>,
-it calls UNIVERSAL::can() instead.
+it calls C<UNIVERSAL::can()> instead.
 
 =back
 
@@ -124,7 +124,7 @@ Philippe "BooK" Bruhat, E<lt>book@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2003-2005, Philippe Bruhat.
+Copyright 2003-2013, Philippe Bruhat.
 
 =head1 LICENSE
 
